@@ -1,12 +1,12 @@
 .onLoad <- function(lib, pkg) { # extended 03-28-06: P.R.
-    require("methods", character = TRUE, quietly = TRUE)
+ #   require("methods", character = TRUE, quietly = TRUE)
 }
 
 .onAttach <- function(libname, pkgname)
 {                                                                    
-    if (.Platform$OS.type == "windows" && require("Biobase")
-        && interactive() && .Platform$GUI == "Rgui") 
-        addVigs2WinMenu("distrDoc")  
+#    if (.Platform$OS.type == "windows" && require("Biobase")
+#        && interactive() && .Platform$GUI == "Rgui")
+#        addVigs2WinMenu("distrDoc")
 
 buildStartupMessage(pkg="distrDoc",  library=libname, 
                     packageHelp=TRUE, # MANUAL="http://www.uni-bayreuth.de/departments/math/org/mathe7/DISTR/distr.pdf",
